Tutorial
========================================

PyDM (Python Display Manager) is a new framework for building control system
graphical user interfaces using Python and Qt.

It provides a system for the drag-and-drop creation of user interfaces using
Qt Designer, and also allows for the creation of displays driven by Python code.

PyDM is intended to span the range from simple displays without any dynamic
behavior to complex high level applications, with the same set of widgets.

Developers can extend the framework with custom widgets for site-specific
tasks, and data plugins for multiple control systems.

.. toctree::
   :maxdepth: 1
   :caption: Before You Start

   intro.rst

.. toctree::
   :maxdepth: 2
   :caption: Introduction

   intro/launcher.rst
   intro/channels.rst
   intro/data_arch.rst
   intro/macros.rst
   intro/widgets.rst
   intro/datasource.rst
   intro/features.rst

.. toctree::
   :maxdepth: 2
   :caption: Hands-on

   action/tutorial.rst
   action/intro_designer.rst
   action/designer.rst
   action/intro_python.rst
   action/little_code.rst
   action/python.rst

.. toctree::
   :maxdepth: 1
   :caption: Contributing

   contrib/help.rst
   contrib/requests.rst

.. toctree::
   :maxdepth: 1
   :caption: Links
   :hidden:
